==> haskell-lazysmallcheck-0.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lazysmallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lazysmallcheck
version:              0.6
visibility:           public
id:                   lazysmallcheck-0.6-6W4SWCaaBH3DONJm5pJu9i
key:                  lazysmallcheck-0.6-6W4SWCaaBH3DONJm5pJu9i
license:              BSD-3-Clause
maintainer:           Matthew Naylor <mfn@cs.york.ac.uk>
author:               Matthew Naylor and Fredrik Lindblad
homepage:             http://www.cs.york.ac.uk/~mfn/lazysmallcheck/
synopsis:             A library for demand-driven testing of Haskell programs
description:
    Lazy SmallCheck is a library for exhaustive, demand-driven testing of
    Haskell programs.  It is based on the idea that if a property holds
    for a partially-defined input then it must also hold for all
    fully-defined refinements of the that input.  Compared to ``eager'\'''\''
    input generation as in SmallCheck, Lazy SmallCheck may require
    significantly fewer test-cases to verify a property for all inputs up
    to a given depth.

category:             Testing
abi:                  92afdc34a53c84c3852a10febb2bd9fd
exposed:              True
exposed-modules:      Test.LazySmallCheck
import-dirs:          /usr/lib/ghc-8.10.4/site-local/lazysmallcheck-0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/lazysmallcheck-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/lazysmallcheck-0.6
hs-libraries:         HSlazysmallcheck-0.6-6W4SWCaaBH3DONJm5pJu9i
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-lazysmallcheck/html/lazysmallcheck.haddock

haddock-html:         /usr/share/doc/haskell-lazysmallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lazysmallcheck-0.6-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lazysmallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lazysmallcheck
version:              0.6
visibility:           public
id:                   lazysmallcheck-0.6-v7dsVOAHOTE0P93Mms7bF
key:                  lazysmallcheck-0.6-v7dsVOAHOTE0P93Mms7bF
license:              BSD-3-Clause
maintainer:           Matthew Naylor <mfn@cs.york.ac.uk>
author:               Matthew Naylor and Fredrik Lindblad
homepage:             http://www.cs.york.ac.uk/~mfn/lazysmallcheck/
synopsis:             A library for demand-driven testing of Haskell programs
description:
    Lazy SmallCheck is a library for exhaustive, demand-driven testing of
    Haskell programs.  It is based on the idea that if a property holds
    for a partially-defined input then it must also hold for all
    fully-defined refinements of the that input.  Compared to ``eager'\'''\''
    input generation as in SmallCheck, Lazy SmallCheck may require
    significantly fewer test-cases to verify a property for all inputs up
    to a given depth.

category:             Testing
abi:                  d0ba4f515c4dcf0c9ebff00c2b5ead8c
exposed:              True
exposed-modules:      Test.LazySmallCheck
import-dirs:          /usr/lib/ghc-8.10.5/site-local/lazysmallcheck-0.6
library-dirs:         /usr/lib/ghc-8.10.5/site-local/lazysmallcheck-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/lazysmallcheck-0.6
hs-libraries:         HSlazysmallcheck-0.6-v7dsVOAHOTE0P93Mms7bF
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-lazysmallcheck/html/lazysmallcheck.haddock

haddock-html:         /usr/share/doc/haskell-lazysmallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
